@@ -108,6 +108,9 @@ class InstrumentDialog(QtGui.QDialog):
 		else:
 			self.ui.minvelocity.setValue(50)
 
+		if 'chance' in i.params:
+			self.ui.chance.setValue(i.params['chance'])
+
 		self.ui.channel.setEnabled(True)
 		if 'channel' in i.params:
 			self.ui.channel.setValue(i.params["channel"])
